#global commit 311849653c0e3e6c2c9c22f430ea37a59e5f1592
#global shortcommit %%(c=%%{commit}; echo ${c:0:7})

# Update to submodule revision as in https://github.com/apitrace/apitrace/tree/master/thirdparty when updating
%global libbacktrace_commit 8602fda64e78f1f46563220f2ee9f7e70819c51d
%global libbacktrace_shortcommit %(c=%{libbacktrace_commit}; echo ${c:0:7})

Name:           apitrace
Epoch:          1
Version:        12.0
Release:        %mkrel %{?commit:0.git%{shortcommit}.}4
Group:          Graphics/Utilities
Summary:        Tools for tracing OpenGL
License:        MIT
URL:            https://apitrace.github.io/
%if 0%{?commit:1}
# git clone --recursive https://github.com/apitrace/apitrace.git
# cd apitrace
# git archive --prefix=apitrace-$commit/ -o ../apitrace-${commit:0:7}.tar $commit
# git submodule foreach --recursive "git archive --prefix=apitrace-$commit/\$path/ --output=\$sha1.tar HEAD && tar --concatenate --file=$(pwd)/../apitrace-${commit:0:7}.tar \$sha1.tar && rm \$sha1.tar"
# cd ..
# gzip apitrace-${commit:0:7}.tar
Source0:        apitrace-%{shortcommit}.tar.gz
%else
Source0:        https://github.com/apitrace/apitrace/archive/%{version}/apitrace-%{version}.tar.gz
%endif
Source1:        https://github.com/ianlancetaylor/libbacktrace/archive/%{libbacktrace_commit}/libbacktrace-%{libbacktrace_shortcommit}.tar.gz
Source2:        qapitrace.desktop
Source3:        qapitrace.appdata.xml

# Don't require third-party submodules
Patch0:         apitrace_nosubmodules-3118496.patch
# From https://gcc.gnu.org/git/gitweb.cgi?p=gcc.git;h=690180eb4b35df3f4b5def690878ecaeb5492e41
Patch1:         apitrace-3118496-fix-libbacktrace-8602fda-btest.patch
Patch2:         0001-apitrace-fix-include-for-GCC-15.patch

BuildRequires:  cmake
BuildRequires:  appstream-util
BuildRequires:  brotli-devel
BuildRequires:  desktop-file-utils
BuildRequires:  git-core
BuildRequires:  libstdc++-static-devel
BuildRequires:  pkgconfig(libdw)
BuildRequires:  pkgconfig(libdwarf)
BuildRequires:  pkgconfig(gtest)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(python3)
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6Network)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  pkgconfig(snappy)
BuildRequires:  pkgconfig(xext)

# scripts/snapdiff.py
Requires:       python3-pillow

# See http://fedoraproject.org/wiki/Packaging:No_Bundled_Libraries#Packages_granted_exceptions
Provides:       bundled(md5-plumb)
# See https://fedorahosted.org/fpc/ticket/429
Provides:       bundled(libbacktrace)
# Modified http://create.stephan-brumme.com/crc32/, see thirdparty/crc32c/README.md
Provides:       bundled(crc32c)
#
Provides:       %{name}%{_isa} = %{epoch}:%{version}-%{release}


%description
apitrace consists of a set of tools to:
 * trace OpenGL and OpenGL ES  APIs calls to a file;
 * replay OpenGL and OpenGL ES calls from a file
 * inspect OpenGL state at any call while retracing
 * visualize and edit trace files


%package gui
Summary:        Graphical frontend for apitrace
Requires:       %{name}%{_isa} = %{epoch}:%{version}-%{release}

%description gui
This package contains qapitrace, the Graphical frontend for apitrace.


%prep
%if 0%{?commit:1}
%autosetup -p1 -n %{name}-%{commit} -a1
%else
%autosetup -p1 -n %{name}-%{version} -a1
%endif

# Remove bundled libraries, except khronos headers
rm -rf `ls -1d thirdparty/* | grep -Ev "(khronos|md5|crc32c|libbacktrace.cmake|support|CMakeLists.txt)"`

# Add bundled libbacktrace
mv libbacktrace-%{libbacktrace_commit} thirdparty/libbacktrace


%build
%cmake -DENABLE_STATIC_SNAPPY=OFF \
       -DENABLE_QT6=ON
%cmake_build


%install
%cmake_install

# Install doc through %%doc
rm -rf %{buildroot}%{_docdir}/

# Install desktop file
desktop-file-install --dir=%{buildroot}%{_datadir}/applications/ %{SOURCE2}

# Install appdata file
install -Dpm 0644 %{SOURCE3} %{buildroot}%{_datadir}/appdata/qapitrace.appdata.xml
%{_bindir}/appstream-util validate-relax --nonet %{buildroot}%{_datadir}/appdata/qapitrace.appdata.xml

# highlight.py is not a script
chmod 0644 %{buildroot}%{_libdir}/%{name}/scripts/highlight.py


%check
# If run through ctest, libbacktrace_btest will fail with
#     ERROR: descriptor 3 still open after tests complete
# This is due to https://gitlab.kitware.com/cmake/cmake/-/issues/18863
# So, run the test outside of ctest
pushd %{_vpath_builddir}
ctest --output-on-failure --force-new-ctest-process -j 1 -E libbacktrace_btest
./btest
popd


%files
%license LICENSE
%doc README.markdown docs/*
%{_bindir}/%{name}
%{_bindir}/eglretrace
%{_bindir}/glretrace
%{_bindir}/gltrim
%{_libdir}/%{name}/

%files gui
%{_bindir}/qapitrace
%{_datadir}/applications/qapitrace.desktop
%{_datadir}/appdata/qapitrace.appdata.xml



%changelog
* Tue May 06 2025 papoteur <papoteur> 1:12.0-4.mga10
+ Revision: 2181258
- fix build with GCC15 adding include

* Sun Apr 06 2025 daviddavid <daviddavid> 1:12.0-3.mga10
+ Revision: 2173923
- disable procps support, deprecated upstream:
  https://github.com/apitrace/apitrace/issues/932
- rebuild for new procps-ng 4.0.5

* Wed Jun 05 2024 daviddavid <daviddavid> 1:12.0-2.mga10
+ Revision: 2070020
- add ubuntu patch to port to libproc2
- fix release tag

* Wed Jun 05 2024 daviddavid <daviddavid> 1:12.0-.1.mga10
+ Revision: 2069895
- new version: 12.0

* Sun Nov 05 2023 daviddavid <daviddavid> 1:11.1-2.git3118496.2.mga10
+ Revision: 2004637
- switch to Qt6
- disable procps support until an upstream port to 4.x

* Thu Nov 24 2022 ghibo <ghibo> 1:11.1-2.git3118496.1.mga9
+ Revision: 1910715
- Really fix btest
- Add Patch1 to fix btest
- Add git-core to BR
- Update to git release as of 20221116.
- Update bundled libbacktrace.
- Rework Patch0.
- Call ctest with -j1.
- Remove delay before btest as doesn't fix the build
- Introduce a delay before running btest
- Fix libstdc++-static-devel in BR
- Add libdw, stdc++-static-devel, xext to BRs
- Bump epoch to fix BS package rejecting due to higher git version
- Rebuild in a fresh system to fix build fail (autobuild)
+ papoteur <papoteur>
- Fix file list
+ neoclust <neoclust>
- New version 11.1
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild
+ akien <akien>
- Version 10.0, loosely synced with Fedora
- Add Epoch 1 since we go from undefined date-based versionining to proper numbers

* Fri Jan 01 2021 akien <akien> 20201219-0.git4a2d21f.1.mga8
+ Revision: 1667638
- Snapshot 20201219

* Wed Dec 16 2020 umeabot <umeabot> 20200918-0.git1aa8391.2.mga8
+ Revision: 1658132
- Rebuild for new Qt5

* Fri Oct 16 2020 akien <akien> 20200918-0.git1aa8391.1.mga8
+ Revision: 1636461
- Update to 20200918, remove patch that broke libbacktrace test

* Wed Feb 19 2020 umeabot <umeabot> 20200103-0.gitffb366c.3.mga8
+ Revision: 1544337
- Mageia 8 Mass Rebuild

* Sat Jan 25 2020 daviddavid <daviddavid> 20200103-0.gitffb366c.2.mga8
+ Revision: 1482899
- rebuild for new procps-ng 3.3.16

* Sun Jan 19 2020 akien <akien> 20200103-0.gitffb366c.1.mga8
+ Revision: 1481484
- Sync with current master branch (20200103)
+ wally <wally>
- build with new cmake macros

* Wed Apr 03 2019 akien <akien> 20190318-0.git2696613.1.mga7
+ Revision: 1385474
- Adapt to Mageia packaging policy, simplify
- Use date as version, upstream doesn't want to do releases anymore
- Update to 20190318 / 2696613
- import apitrace from Fedora Rawhide


* Thu Jan 31 2019 Fedora Release Engineering <releng@fedoraproject.org> - 8.0-0.2.gitf411d55
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Wed Jan 30 2019 Sandro Mani <manisandro@gmail.com> - 0.8-0.1.gitf411d55
- Update to latest git

* Thu Jul 12 2018 Fedora Release Engineering <releng@fedoraproject.org> - 7.1-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Sun Feb 18 2018 Sandro Mani <manisandro@gmail.com> - 7.1-11
- Add missing BR: gcc-c++, make

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 7.1-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Sat Feb 03 2018 Sandro Mani <manisandro@gmail.com> - 7.1-9
- Rebuild

* Mon Oct 30 2017 Sandro Mani <manisandro@gmail.com> - 7.1-8
- Correctly remove thirdparty bundled libraries (#1507659)
- Add BR: libdwarf-devel to enable backtrace support

* Mon Aug 07 2017 Sandro Mani <manisandro@gmail.com> - 7.1-7
- Don't add -nn to the moc options

* Wed Aug 02 2017 Fedora Release Engineering <releng@fedoraproject.org> - 7.1-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 7.1-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Mon May 15 2017 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 7.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_27_Mass_Rebuild

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 7.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 7.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Nov 25 2015 Sandro Mani <manisandro@gmail.com> - 7.1-1
- Update to 7.1

* Wed Sep 16 2015 Richard Hughes <rhughes@redhat.com> - 7.0-2
- Fix the AppData file to actually validate

* Thu Jul 23 2015 Sandro Mani <manisandro@gmail.com> - 7.0-1
- Update to 7.0

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 6.1-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat May 02 2015 Kalev Lember <kalevlember@gmail.com> - 6.1-4
- Rebuilt for GCC 5 C++11 ABI change

* Mon Mar 02 2015 Sandro Mani <manisandro@gmail.com> - 6.1-3
- Remove dlsym hack, use %%define __filter_GLIBC_PRIVATE 1

* Fri Jan 16 2015 Sandro Mani <manisandro@gmail.com> - 6.1-2
- Fix appdata file

* Fri Jan 16 2015 Sandro Mani <manisandro@gmail.com> - 6.1-1
- Update to 6.1

* Tue Jan 06 2015 Sandro Mani <manisandro@gmail.com> - 6.0-2
- Re-introduce dlsym hack

* Mon Jan 05 2015 Sandro Mani <manisandro@gmail.com> - 6.0-1
- Update to 6.0
- Ship appdata file

* Fri Aug 15 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 5.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Wed Jun 11 2014 Adam Jackson <ajax@redhat.com> 5.0-3
- Fix dlsym hack to work on arm (and probably others)

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 5.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Tue May 13 2014 Sandro Mani <manisandro@gmail.com> - 5.0-1
- Update to 5.0

* Fri Mar 07 2014 Sandro Mani <manisandro@gmail.com> - 4.0-5
- Split off libs package
- Allow tracing 32bit binaries on 64bit

* Mon Nov 18 2013 Sandro Mani <manisandro@gmail.com> - 4.0-4
- chmod 0644 scripts/highlight.py
- Fix all python shebangs according to fedora guidelines
- Use BR: python2-devel
- Split off qapitrace into subpackage

* Sat Nov 16 2013 Sandro Mani <manisandro@gmail.com> - 4.0-3
- Fix desktop-file-install syntax

* Sat Nov 16 2013 Sandro Mani <manisandro@gmail.com> - 4.0-2
- Fix %%{_buildroot} -> %%{buildroot} typo
- Remove explicit BRs which are implicit

* Wed Nov 13 2013 Sandro Mani <manisandro@gmail.com> - 4.0-1
- Initial package
